==> CGI-Application-Plugin-Apache-0.10.tar.gz: CGI-Application-Plugin-Apache-0.10/lib/CGI/Application/Plugin/Apache/Request.pm <==
package CGI::Application::Plugin::Apache::Request;
use strict;
use base 'Apache::Request';
use Apache::Cookie;
use Apache::URI;
use HTML::GenerateUtil;

my $MP2;

BEGIN {
    # only do stuff if we are running under mod_perl
    if( $ENV{MOD_PERL} ) {
        require mod_perl;
        $MP2 = $mod_perl::VERSION >= 1.99 ? 1 : 0;
        # if we are under mod_perl 2
        if( $MP2 ) {
            require Apache::Upload;
            import Apache::Upload ();
        } else {
        }
    }
}


sub new {
    my($class, @args) = @_;
    return bless $class->SUPER::new(@args), $class;
}

sub param {
    my ($self, @args) = @_;
    # if we aren't in mod_perl 2 or we just want the value of a param
    if( !$MP2 || scalar @args <= 1) {
        return $self->SUPER::param(@args);
    # else we want to set the value of the param
    } else {
        return $self->args->{$args[0]} = $args[1];
    }
}


=pod

=head1 NAME

CGI::Application::Plugin::Apache::Request

=head1 DESCRIPTION

This package is just a wrapper around Apache::Request to add L<CGI.pm|CGI> compatible
methods. The interface and usage is exactly the same as L<CGI.pm|CGI>.

=over 8

=item delete()

=cut

sub delete {
    my ($self, @args) = @_;
    my $table = $self->parms();
    foreach my $arg (@args) {
        delete $table->{$arg};
    }
}

=item delete_all()

=cut

sub delete_all {
    my $self = shift;
    my $table = $self->parms();
    my @args = keys %$table;
    foreach my $arg (@args) {
        delete $table->{$arg};
    }
}

=item cookie()

=cut

sub cookie {
    my ($self, @args) = @_;
    if($#args == 0) {
        # if we just have a name of a cookie then retrieve the value of the cookie
        my $cookies = Apache::Cookie->fetch();
        return $cookies->{$args[0]}->value;
    } else {
        # else we have several values so try and create a new cookie
        return Apache::Cookie->new($self, @args);
    }
}

=item Dump()

=cut

sub Dump {
    my $self = shift;
    my($param,$value,@result);
    return '<ul></ul>' unless $self->param;
    push(@result,"<ul>");
    foreach $param ($self->param) {
        my $name = $self->escapeHTML($param);
        push(@result,"<li><strong>$name</strong></li>");
        push(@result,"<ul>");
        foreach $value ($self->param($param)) {
            $value = $self->escapeHTML($value);
            push(@result,"<li>$value</li>");
        }
        push(@result,"</ul>");
    }
    push(@result,"</ul>");
    return join("\n",@result);
}

=item Vars()

=cut

sub Vars {
    my $self = shift;
    my @params = $self->param();
    my %Vars = ();
    foreach my $param (@params) {
        my @values = $self->param($param);
        if( scalar @values == 1 ) {
            $Vars{$param} = $values[0];
        } else {
            $Vars{$param} = \@values;
        }
    }

    if(wantarray) {
        return %Vars;
    } else {
        return \%Vars;
    }
}

=item escapeHTML()

=cut

sub escapeHTML {
    my ($self, $value) = @_;
    $value = HTML::GenerateUtil::escape_html($value, 
        (
            $HTML::GenerateUtil::EH_LFTOBR 
            | $HTML::GenerateUtil::EH_SPTONBSP 
            | $HTML::GenerateUtil::EH_LEAVEKNOWN
        )
    ); 
    return $value;
}

=item upload()

=cut

sub upload {
    my ($self, $file) = @_;
    # if they want a specific one, then lets give them the file handle
    if( $file ) {
        return $self->SUPER::upload($file)->fh();
    # else they want them all
    } else {
        my @files = $self->SUPER::upload();
        @files = map { $self->SUPER::upload($_)->fh() } @files;
        return @files;
    }
}

1;

__END__

=item 

=back

Please see L<CGI::Application::Plugin::Apache> for more details.

==> CGI-Application-Plugin-Apache-0.11.tar.gz: CGI-Application-Plugin-Apache-0.11/lib/CGI/Application/Plugin/Apache/Request.pm <==
package CGI::Application::Plugin::Apache::Request;
use strict;
use HTML::GenerateUtil;
our $MP2;
our @ISA;
BEGIN {
    # only do stuff if we are running under mod_perl
    if( $ENV{MOD_PERL} ) {
        $MP2 = $ENV{MOD_PERL_API_VERSION} == 2;
        # if we are under mod_perl 2.x
        if( $MP2 ) {
            require Apache2::Request;
            push(@ISA, 'Apache2::Request');
            require Apache2::Cookie;
            import Apache2::Cookie ();
            require Apache2::URI;
            import Apache2::URI ();
            require Apache2::Upload;
            import Apache2::Upload ();
        # else we are under mod_perl 1.x
        } else {
            require Apache::Request;
            push(@ISA, 'Apache::Request');
            require Apache::Cookie;
            import Apache::Cookie ();
            require Apache::URI;
            import Apache::URI ();
        }
    }
}



sub new {
    my($class, @args) = @_;
    return bless $class->SUPER::new(@args), $class;
}

sub param {
    my ($self, @args) = @_;
    # if we aren't in mod_perl 2 or we just want the value of a param
    if( !$MP2 || scalar @args <= 1) {
        return $self->SUPER::param(@args);
    # else we want to set the value of the param
    } else {
        return $self->args->{$args[0]} = $args[1];
    }
}


=pod

=head1 NAME

CGI::Application::Plugin::Apache::Request

=head1 DESCRIPTION

This package is just a wrapper around Apache::Request to add L<CGI.pm|CGI> compatible
methods. The interface and usage is exactly the same as L<CGI.pm|CGI>.

=over 8

=item delete()

=cut

sub delete {
    my ($self, @args) = @_;
    my $table = $self->parms();
    foreach my $arg (@args) {
        delete $table->{$arg};
    }
}

=item delete_all()

=cut

sub delete_all {
    my $self = shift;
    my $table = $self->parms();
    my @args = keys %$table;
    foreach my $arg (@args) {
        delete $table->{$arg};
    }
}

=item cookie()

=cut

sub cookie {
    my ($self, @args) = @_;
    if($#args == 0) {
        # if we just have a name of a cookie then retrieve the value of the cookie
        my $cookies = $MP2 ? Apache2::Cookie->fetch() : Apache::Cookie->fetch();
        return $cookies->{$args[0]}->value;
    } else {
        # else we have several values so try and create a new cookie
        return $MP2 ? 
            Apache2::Cookie->new($self, @args)
            : Apache::Cookie->new($self, @args);
    }
}

=item Dump()

=cut

sub Dump {
    my $self = shift;
    my($param,$value,@result);
    return '<ul></ul>' unless $self->param;
    push(@result,"<ul>");
    foreach $param ($self->param) {
        my $name = $self->escapeHTML($param);
        push(@result,"<li><strong>$name</strong></li>");
        push(@result,"<ul>");
        foreach $value ($self->param($param)) {
            $value = $self->escapeHTML($value);
            push(@result,"<li>$value</li>");
        }
        push(@result,"</ul>");
    }
    push(@result,"</ul>");
    return join("\n",@result);
}

=item Vars()

=cut

sub Vars {
    my $self = shift;
    my @params = $self->param();
    my %Vars = ();
    foreach my $param (@params) {
        my @values = $self->param($param);
        if( scalar @values == 1 ) {
            $Vars{$param} = $values[0];
        } else {
            $Vars{$param} = \@values;
        }
    }

    if(wantarray) {
        return %Vars;
    } else {
        return \%Vars;
    }
}

=item escapeHTML()

=cut

sub escapeHTML {
    my ($self, $value) = @_;
    $value = HTML::GenerateUtil::escape_html($value, 
        (
            $HTML::GenerateUtil::EH_LFTOBR 
            | $HTML::GenerateUtil::EH_SPTONBSP 
            | $HTML::GenerateUtil::EH_LEAVEKNOWN
        )
    ); 
    return $value;
}

=item upload()

=cut

sub upload {
    my ($self, $file) = @_;
    # if they want a specific one, then lets give them the file handle
    if( $file ) {
        return $self->SUPER::upload($file)->fh();
    # else they want them all
    } else {
        my @files = $self->SUPER::upload();
        @files = map { $self->SUPER::upload($_)->fh() } @files;
        return @files;
    }
}

1;

__END__

=item 

=back

Please see L<CGI::Application::Plugin::Apache> for more details.
